package
Version:
v0.0.0-...-a273035
Opens a new window with list of versions in this module.
Published: May 5, 2021
License: GPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type RedhatCVE struct {
Code string `json:"CVE"`
Description string `json:"bugzilla_description"`
URL string `json:"bugzilla"`
Severity string `json:"severity"`
PublicDate string `json:"public_date"`
AffectedPackages []string `json:"affected_packages"`
Score string `json:"cvss3_score"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.